"""
Endpoints to manage Codespaces using the REST API.
"""


class Codespaces:
    # pylint: disable=too-many-public-methods
    """
    Endpoints to manage Codespaces using the REST API.
    """

    def __init__(self, client):
        """
        Initialize the Codespaces class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organization_secrets(self, org, payload=None):
        """
        List organization secrets
        https://docs.github.com/rest/reference/codespaces#list-organization-secrets
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/organizations/{org}/codespaces/secrets"
        response = self._execute("get", url, payload)
        return response

    def list_codespaces_for_the_organization(self, org, payload=None):
        """
        List codespaces for the organization
        https://docs.github.com/rest/reference/codespaces#list-in-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/codespaces"
        response = self._execute("get", url, payload)
        return response

    def list_codespaces_for_a_user_in_organization(self, org, username, payload=None):
        """
        List codespaces for a user in organization
        https://docs.github.com/rest/reference/codespaces#get-codespaces-for-user-in-org
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/members/{username}/codespaces"
        response = self._execute("get", url, payload)
        return response

    def delete_a_codespace_from_the_organization(self, org, username, codespace_name, payload=None):
        """
        Delete a codespace from the organization
        https://docs.github.com/rest/reference/codespaces
        Attributes:
        Path Parameters:
        org
        username
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}/codespaces/{codespace_name}"
        response = self._execute("delete", url, payload)
        return response

    def export_a_codespace_for_an_organization_user(
        self, org, username, codespace_name, payload=None
    ):
        """
        Export a codespace for an organization user
        https://docs.github.com/rest/reference/codespaces
        Attributes:
        Path Parameters:
        org
        username
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}/codespaces/{codespace_name}/exports"
        response = self._execute("post", url, payload)
        return response

    def start_a_codespace_for_an_organization_user(
        self, org, username, codespace_name, payload=None
    ):
        """
        Start a codespace for an organization user
        https://docs.github.com/rest/reference/codespaces
        Attributes:
        Path Parameters:
        org
        username
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}/codespaces/{codespace_name}/start"
        response = self._execute("post", url, payload)
        return response

    def stop_a_codespace_for_an_organization_user(
        self, org, username, codespace_name, payload=None
    ):
        """
        Stop a codespace for an organization user
        https://docs.github.com/rest/reference/codespaces
        Attributes:
        Path Parameters:
        org
        username
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}/codespaces/{codespace_name}/stop"
        response = self._execute("post", url, payload)
        return response

    def list_codespaces_in_a_repository_for_the_authenticated_user(self, owner, repo, payload=None):
        """
        List codespaces in a repository for the authenticated user
        https://docs.github.com/rest/reference/codespaces#list-codespaces-in-a-repository-for-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces"
        response = self._execute("get", url, payload)
        return response

    def create_a_codespace_in_a_repository(self, owner, repo, payload=None):
        """
        Create a codespace in a repository
        https://docs.github.com/rest/reference/codespaces#create-a-codespace-in-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces"
        response = self._execute("post", url, payload)
        return response

    def list_devcontainer_configurations_in_a_repository_for_the_authenticated_user(
        self, owner, repo, payload=None
    ):
        """
        List devcontainer configurations in a repository for the authenticated user
        https://docs.github.com/rest/reference/codespaces#list-devcontainers-in-a-repository-for-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/devcontainers"
        response = self._execute("get", url, payload)
        return response

    def list_available_machine_types_for_a_repository(self, owner, repo, payload=None):
        """
        List available machine types for a repository
        https://docs.github.com/rest/reference/codespaces#list-available-machine-types-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        location
         client_ip
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/machines"
        response = self._execute("get", url, payload)
        return response

    def get_default_attributes_for_a_codespace(self, owner, repo, payload=None):
        """
        Get default attributes for a codespace
        https://docs.github.com/rest/reference/codespaces#preview-attributes-for-a-new-codespace
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        ref
         client_ip
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/new"
        response = self._execute("get", url, payload)
        return response

    def list_repository_secrets(self, owner, repo, payload=None):
        """
        List repository secrets
        https://docs.github.com/rest/reference/codespaces#list-repository-secrets
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_public_key(self, owner, repo, payload=None):
        """
        Get a repository public key
        https://docs.github.com/rest/reference/codespaces#get-a-repository-public-key
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Get a repository secret
        https://docs.github.com/rest/reference/codespaces#get-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Create or update a repository secret
        https://docs.github.com/rest/reference/codespaces#create-or-update-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Delete a repository secret
        https://docs.github.com/rest/reference/codespaces#delete-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/codespaces/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response

    def create_a_codespace_from_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Create a codespace from a pull request
        https://docs.github.com/rest/reference/codespaces#create-a-codespace-from-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/codespaces"
        response = self._execute("post", url, payload)
        return response

    def list_codespaces_for_the_authenticated_user(self, payload=None):
        """
        List codespaces for the authenticated user
        https://docs.github.com/rest/reference/codespaces#list-codespaces-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
         repository-id-in-query
        """
        url = self._base_url + "/user/codespaces"
        response = self._execute("get", url, payload)
        return response

    def create_a_codespace_for_the_authenticated_user(self, payload=None):
        """
        Create a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#create-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/codespaces"
        response = self._execute("post", url, payload)
        return response

    def list_secrets_for_the_authenticated_user(self, payload=None):
        """
        List secrets for the authenticated user
        https://docs.github.com/rest/reference/codespaces#list-secrets-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/codespaces/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_public_key_for_the_authenticated_user(self, payload=None):
        """
        Get public key for the authenticated user
        https://docs.github.com/rest/reference/codespaces#get-public-key-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/codespaces/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_a_secret_for_the_authenticated_user(self, secret_name, payload=None):
        """
        Get a secret for the authenticated user
        https://docs.github.com/rest/reference/codespaces#get-a-secret-for-the-authenticated-user
        Attributes:
        Path Parameters:
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_a_secret_for_the_authenticated_user(self, secret_name, payload=None):
        """
        Create or update a secret for the authenticated user
        https://docs.github.com/rest/reference/codespaces#create-or-update-a-secret-for-the-authenticated-user
        Attributes:
        Path Parameters:
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_secret_for_the_authenticated_user(self, secret_name, payload=None):
        """
        Delete a secret for the authenticated user
        https://docs.github.com/rest/reference/codespaces#delete-a-secret-for-the-authenticated-user
        Attributes:
        Path Parameters:
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response

    def list_selected_repositories_for_a_user_secret(self, secret_name, payload=None):
        """
        List selected repositories for a user secret
        https://docs.github.com/rest/reference/codespaces#list-selected-repositories-for-a-user-secret
        Attributes:
        Path Parameters:
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/secrets/{secret_name}/repositories"
        response = self._execute("get", url, payload)
        return response

    def set_selected_repositories_for_a_user_secret(self, secret_name, payload=None):
        """
        Set selected repositories for a user secret
        https://docs.github.com/rest/reference/codespaces#set-selected-repositories-for-a-user-secret
        Attributes:
        Path Parameters:
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/secrets/{secret_name}/repositories"
        response = self._execute("put", url, payload)
        return response

    def add_a_selected_repository_to_a_user_secret(self, secret_name, repository_id, payload=None):
        """
        Add a selected repository to a user secret
        https://docs.github.com/rest/reference/codespaces#add-a-selected-repository-to-a-user-secret
        Attributes:
        Path Parameters:
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/user/codespaces/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_a_selected_repository_from_a_user_secret(
        self, secret_name, repository_id, payload=None
    ):
        """
        Remove a selected repository from a user secret
        https://docs.github.com/rest/reference/codespaces#remove-a-selected-repository-from-a-user-secret
        Attributes:
        Path Parameters:
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/user/codespaces/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Get a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#get-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}"
        response = self._execute("get", url, payload)
        return response

    def update_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Update a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#update-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Delete a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#delete-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}"
        response = self._execute("delete", url, payload)
        return response

    def export_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Export a codespace for the authenticated user
        N/A
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}/exports"
        response = self._execute("post", url, payload)
        return response

    def get_details_about_a_codespace_export(self, codespace_name, export_id, payload=None):
        """
        Get details about a codespace export
        N/A
        Attributes:
        Path Parameters:
        codespace_name
        export_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}/exports/{export_id}"
        response = self._execute("get", url, payload)
        return response

    def list_machine_types_for_a_codespace(self, codespace_name, payload=None):
        """
        List machine types for a codespace
        https://docs.github.com/rest/reference/codespaces#list-machine-types-for-a-codespace
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}/machines"
        response = self._execute("get", url, payload)
        return response

    def start_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Start a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#start-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}/start"
        response = self._execute("post", url, payload)
        return response

    def stop_a_codespace_for_the_authenticated_user(self, codespace_name, payload=None):
        """
        Stop a codespace for the authenticated user
        https://docs.github.com/rest/reference/codespaces#stop-a-codespace-for-the-authenticated-user
        Attributes:
        Path Parameters:
        codespace_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/codespaces/{codespace_name}/stop"
        response = self._execute("post", url, payload)
        return response



"""
Administer a GitHub enterprise.
"""


class EnterpriseAdmin:
    # pylint: disable=too-many-public-methods
    """
    Administer a GitHub enterprise.
    """

    def __init__(self, client):
        """
        Initialize the EnterpriseAdmin class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_github_actions_permissions_for_an_enterprise(self, enterprise, payload=None):
        """
        Get GitHub Actions permissions for an enterprise
        https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions"
        response = self._execute("get", url, payload)
        return response

    def set_github_actions_permissions_for_an_enterprise(self, enterprise, payload=None):
        """
        Set GitHub Actions permissions for an enterprise
        https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions"
        response = self._execute("put", url, payload)
        return response

    def list_selected_organizations_enabled_for_github_actions_in_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        List selected organizations enabled for GitHub Actions in an enterprise
        https://docs.github.com/rest/reference/actions#list-selected-organizations-enabled-for-github-actions-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations"
        response = self._execute("get", url, payload)
        return response

    def set_selected_organizations_enabled_for_github_actions_in_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        Set selected organizations enabled for GitHub Actions in an enterprise
        https://docs.github.com/rest/reference/actions#set-selected-organizations-enabled-for-github-actions-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations"
        response = self._execute("put", url, payload)
        return response

    def enable_a_selected_organization_for_github_actions_in_an_enterprise(
        self, enterprise, org_id, payload=None
    ):
        """
        Enable a selected organization for GitHub Actions in an enterprise
        https://docs.github.com/rest/reference/actions#enable-a-selected-organization-for-github-actions-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        org_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations/{org_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def disable_a_selected_organization_for_github_actions_in_an_enterprise(
        self, enterprise, org_id, payload=None
    ):
        """
        Disable a selected organization for GitHub Actions in an enterprise
        https://docs.github.com/rest/reference/actions#disable-a-selected-organization-for-github-actions-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        org_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/enterprises/{enterprise}/actions/permissions/organizations/{org_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_allowed_actions_and_reusable_workflows_for_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        Get allowed actions and reusable workflows for an enterprise
        https://docs.github.com/rest/reference/actions#get-allowed-actions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/selected-actions"
        response = self._execute("get", url, payload)
        return response

    def set_allowed_actions_and_reusable_workflows_for_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        Set allowed actions and reusable workflows for an enterprise
        https://docs.github.com/rest/reference/actions#set-allowed-actions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/selected-actions"
        response = self._execute("put", url, payload)
        return response

    def list_self_hosted_runner_groups_for_an_enterprise(self, enterprise, payload=None):
        """
        List self-hosted runner groups for an enterprise
        https://docs.github.com/rest/reference/actions#list-self-hosted-runner-groups-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        per-page
         page
         visible-to-organization
        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups"
        response = self._execute("get", url, payload)
        return response

    def create_a_self_hosted_runner_group_for_an_enterprise(self, enterprise, payload=None):
        """
        Create a self-hosted runner group for an enterprise
        https://docs.github.com/rest/reference/actions#create-self-hosted-runner-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups"
        response = self._execute("post", url, payload)
        return response

    def get_a_self_hosted_runner_group_for_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        Get a self-hosted runner group for an enterprise
        https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_self_hosted_runner_group_for_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        Update a self-hosted runner group for an enterprise
        https://docs.github.com/rest/reference/actions#update-a-self-hosted-runner-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_self_hosted_runner_group_from_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        Delete a self-hosted runner group from an enterprise
        https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-group-from-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        List organization access to a self-hosted runner group in an enterprise
        https://docs.github.com/rest/reference/actions#list-organization-access-to-a-self-hosted-runner-group-in-a-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations"
        )
        response = self._execute("get", url, payload)
        return response

    def set_organization_access_for_a_self_hosted_runner_group_in_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        Set organization access for a self-hosted runner group in an enterprise
        https://docs.github.com/rest/reference/actions#set-organization-access-to-a-self-hosted-runner-group-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations"
        )
        response = self._execute("put", url, payload)
        return response

    def add_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
        self, enterprise, runner_group_id, org_id, payload=None
    ):
        """
        Add organization access to a self-hosted runner group in an enterprise
        https://docs.github.com/rest/reference/actions#add-organization-access-to-a-self-hosted-runner-group-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        org_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations/{org_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("put", url, payload)
        return response

    def remove_organization_access_to_a_self_hosted_runner_group_in_an_enterprise(
        self, enterprise, runner_group_id, org_id, payload=None
    ):
        """
        Remove organization access to a self-hosted runner group in an enterprise
        https://docs.github.com/rest/reference/actions#remove-organization-access-to-a-self-hosted-runner-group-in-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        org_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/organizations/{org_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_self_hosted_runners_in_a_group_for_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        List self-hosted runners in a group for an enterprise
        https://docs.github.com/rest/reference/actions#list-self-hosted-runners-in-a-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners"
        )
        response = self._execute("get", url, payload)
        return response

    def set_self_hosted_runners_in_a_group_for_an_enterprise(
        self, enterprise, runner_group_id, payload=None
    ):
        """
        Set self-hosted runners in a group for an enterprise
        https://docs.github.com/rest/reference/actions#set-self-hosted-runners-in-a-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners"
        )
        response = self._execute("put", url, payload)
        return response

    def add_a_self_hosted_runner_to_a_group_for_an_enterprise(
        self, enterprise, runner_group_id, runner_id, payload=None
    ):
        """
        Add a self-hosted runner to a group for an enterprise
        https://docs.github.com/rest/reference/actions#add-a-self-hosted-runner-to-a-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        runner_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("put", url, payload)
        return response

    def remove_a_self_hosted_runner_from_a_group_for_an_enterprise(
        self, enterprise, runner_group_id, runner_id, payload=None
    ):
        """
        Remove a self-hosted runner from a group for an enterprise
        https://docs.github.com/rest/reference/actions#remove-a-self-hosted-runner-from-a-group-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_group_id
        runner_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/enterprises/{enterprise}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_self_hosted_runners_for_an_enterprise(self, enterprise, payload=None):
        """
        List self-hosted runners for an enterprise
        https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners"
        response = self._execute("get", url, payload)
        return response

    def list_runner_applications_for_an_enterprise(self, enterprise, payload=None):
        """
        List runner applications for an enterprise
        https://docs.github.com/rest/reference/actions#list-runner-applications-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/downloads"
        response = self._execute("get", url, payload)
        return response

    def create_a_registration_token_for_an_enterprise(self, enterprise, payload=None):
        """
        Create a registration token for an enterprise
        https://docs.github.com/rest/reference/actions#create-a-registration-token-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/registration-token"
        response = self._execute("post", url, payload)
        return response

    def create_a_remove_token_for_an_enterprise(self, enterprise, payload=None):
        """
        Create a remove token for an enterprise
        https://docs.github.com/rest/reference/actions#create-a-remove-token-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/remove-token"
        response = self._execute("post", url, payload)
        return response

    def get_a_self_hosted_runner_for_an_enterprise(self, enterprise, runner_id, payload=None):
        """
        Get a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_self_hosted_runner_from_an_enterprise(self, enterprise, runner_id, payload=None):
        """
        Delete a self-hosted runner from an enterprise
        https://docs.github.com/rest/reference/actions#delete-self-hosted-runner-from-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_labels_for_a_self_hosted_runner_for_an_enterprise(
        self, enterprise, runner_id, payload=None
    ):
        """
        List labels for a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
        response = self._execute("get", url, payload)
        return response

    def add_custom_labels_to_a_self_hosted_runner_for_an_enterprise(
        self, enterprise, runner_id, payload=None
    ):
        """
        Add custom labels to a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
        response = self._execute("post", url, payload)
        return response

    def set_custom_labels_for_a_self_hosted_runner_for_an_enterprise(
        self, enterprise, runner_id, payload=None
    ):
        """
        Set custom labels for a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
        response = self._execute("put", url, payload)
        return response

    def remove_all_custom_labels_from_a_self_hosted_runner_for_an_enterprise(
        self, enterprise, runner_id, payload=None
    ):
        """
        Remove all custom labels from a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels"
        response = self._execute("delete", url, payload)
        return response

    def remove_a_custom_label_from_a_self_hosted_runner_for_an_enterprise(
        self, enterprise, runner_id, name, payload=None
    ):
        """
        Remove a custom label from a self-hosted runner for an enterprise
        https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        runner_id
        name
        Payload Parameters:
        runner-label-name
        """
        url = (
            self._base_url + f"/enterprises/{enterprise}/actions/runners/{runner_id}/labels/{name}"
        )
        response = self._execute("delete", url, payload)
        return response

    def get_the_audit_log_for_an_enterprise(self, enterprise, payload=None):
        """
        Get the audit log for an enterprise
        https://docs.github.com/rest/reference/enterprise-admin#get-the-audit-log-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        audit-log-phrase
         audit-log-include
         audit-log-after
         audit-log-before
         audit-log-order
         page
         per-page
        """
        url = self._base_url + f"/enterprises/{enterprise}/audit-log"
        response = self._execute("get", url, payload)
        return response

    def retrieve_enterprise_license_sync_consumed_licenses(self, enterprise, payload=None):
        """
        Retrieve Enterprise License Sync Consumed Licenses
        https://docs.github.com/rest/reference/enterprise-admin#retrieve-enterprise-license-sync-consumed-licenses
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/enterprises/{enterprise}/consumed-licenses"
        response = self._execute("get", url, payload)
        return response

    def provides_license_sync_job_status_for_connected_instances(self, enterprise, payload=None):
        """
        Provides License Sync Job status for connected instances
        https://docs.github.com/rest/reference/enterprise-admin#provides-license-sync-job-status-for-connected-instances
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/license-sync-status"
        response = self._execute("get", url, payload)
        return response

    def list_provisioned_scim_groups_for_an_enterprise(self, enterprise, payload=None):
        """
        List provisioned SCIM groups for an enterprise
        https://docs.github.com/rest/reference/enterprise-admin#list-provisioned-scim-groups-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        start-index
         count
         filter
         excludedAttributes
        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups"
        response = self._execute("get", url, payload)
        return response

    def provision_a_scim_enterprise_group_and_invite_users(self, enterprise, payload=None):
        """
        Provision a SCIM enterprise group and invite users
        https://docs.github.com/rest/reference/enterprise-admin#provision-a-scim-enterprise-group-and-invite-users
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups"
        response = self._execute("post", url, payload)
        return response

    def get_scim_provisioning_information_for_an_enterprise_group(
        self, enterprise, scim_group_id, payload=None
    ):
        """
        Get SCIM provisioning information for an enterprise group
        https://docs.github.com/rest/reference/enterprise-admin#get-scim-provisioning-information-for-an-enterprise-group
        Attributes:
        Path Parameters:
        enterprise
        scim_group_id
        Payload Parameters:
        excludedAttributes
        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
        response = self._execute("get", url, payload)
        return response

    def set_scim_information_for_a_provisioned_enterprise_group(
        self, enterprise, scim_group_id, payload=None
    ):
        """
        Set SCIM information for a provisioned enterprise group
        https://docs.github.com/rest/reference/enterprise-admin#set-scim-information-for-a-provisioned-enterprise-group
        Attributes:
        Path Parameters:
        enterprise
        scim_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
        response = self._execute("put", url, payload)
        return response

    def update_an_attribute_for_a_scim_enterprise_group(
        self, enterprise, scim_group_id, payload=None
    ):
        """
        Update an attribute for a SCIM enterprise group
        https://docs.github.com/rest/reference/enterprise-admin#update-an-attribute-for-a-scim-enterprise-group
        Attributes:
        Path Parameters:
        enterprise
        scim_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_scim_group_from_an_enterprise(self, enterprise, scim_group_id, payload=None):
        """
        Delete a SCIM group from an enterprise
        https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-group-from-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        scim_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Groups/{scim_group_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_scim_provisioned_identities_for_an_enterprise(self, enterprise, payload=None):
        """
        List SCIM provisioned identities for an enterprise
        https://docs.github.com/rest/reference/enterprise-admin#list-scim-provisioned-identities-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        start-index
         count
         filter
        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users"
        response = self._execute("get", url, payload)
        return response

    def provision_and_invite_a_scim_enterprise_user(self, enterprise, payload=None):
        """
        Provision and invite a SCIM enterprise user
        https://docs.github.com/rest/reference/enterprise-admin#provision-and-invite-a-scim-enterprise-user
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users"
        response = self._execute("post", url, payload)
        return response

    def get_scim_provisioning_information_for_an_enterprise_user(
        self, enterprise, scim_user_id, payload=None
    ):
        """
        Get SCIM provisioning information for an enterprise user
        https://docs.github.com/rest/reference/enterprise-admin#get-scim-provisioning-information-for-an-enterprise-user
        Attributes:
        Path Parameters:
        enterprise
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
        response = self._execute("get", url, payload)
        return response

    def set_scim_information_for_a_provisioned_enterprise_user(
        self, enterprise, scim_user_id, payload=None
    ):
        """
        Set SCIM information for a provisioned enterprise user
        https://docs.github.com/rest/reference/enterprise-admin#set-scim-information-for-a-provisioned-enterprise-user
        Attributes:
        Path Parameters:
        enterprise
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
        response = self._execute("put", url, payload)
        return response

    def update_an_attribute_for_a_scim_enterprise_user(
        self, enterprise, scim_user_id, payload=None
    ):
        """
        Update an attribute for a SCIM enterprise user
        https://docs.github.com/rest/reference/enterprise-admin#update-an-attribute-for-a-scim-enterprise-user
        Attributes:
        Path Parameters:
        enterprise
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_scim_user_from_an_enterprise(self, enterprise, scim_user_id, payload=None):
        """
        Delete a SCIM user from an enterprise
        https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-user-from-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        scim_user_id
        Payload Parameters:

        """
        url = self._base_url + f"/scim/v2/enterprises/{enterprise}/Users/{scim_user_id}"
        response = self._execute("delete", url, payload)
        return response



"""
Interact with GitHub Projects.
"""


class Projects:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Projects.
    """

    def __init__(self, client):
        """
        Initialize the Projects class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organization_projects(self, org, payload=None):
        """
        List organization projects
        https://docs.github.com/rest/reference/projects#list-organization-projects
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        state
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/projects"
        response = self._execute("get", url, payload)
        return response

    def create_an_organization_project(self, org, payload=None):
        """
        Create an organization project
        https://docs.github.com/rest/reference/projects#create-an-organization-project
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/projects"
        response = self._execute("post", url, payload)
        return response

    def get_a_project_card(self, card_id, payload=None):
        """
        Get a project card
        https://docs.github.com/rest/reference/projects#get-a-project-card
        Attributes:
        Path Parameters:
        card_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/cards/{card_id}"
        response = self._execute("get", url, payload)
        return response

    def update_an_existing_project_card(self, card_id, payload=None):
        """
        Update an existing project card
        https://docs.github.com/rest/reference/projects#update-a-project-card
        Attributes:
        Path Parameters:
        card_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/cards/{card_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_project_card(self, card_id, payload=None):
        """
        Delete a project card
        https://docs.github.com/rest/reference/projects#delete-a-project-card
        Attributes:
        Path Parameters:
        card_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/cards/{card_id}"
        response = self._execute("delete", url, payload)
        return response

    def move_a_project_card(self, card_id, payload=None):
        """
        Move a project card
        https://docs.github.com/rest/reference/projects#move-a-project-card
        Attributes:
        Path Parameters:
        card_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/cards/{card_id}/moves"
        response = self._execute("post", url, payload)
        return response

    def get_a_project_column(self, column_id, payload=None):
        """
        Get a project column
        https://docs.github.com/rest/reference/projects#get-a-project-column
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/{column_id}"
        response = self._execute("get", url, payload)
        return response

    def update_an_existing_project_column(self, column_id, payload=None):
        """
        Update an existing project column
        https://docs.github.com/rest/reference/projects#update-a-project-column
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/{column_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_project_column(self, column_id, payload=None):
        """
        Delete a project column
        https://docs.github.com/rest/reference/projects#delete-a-project-column
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/{column_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_project_cards(self, column_id, payload=None):
        """
        List project cards
        https://docs.github.com/rest/reference/projects#list-project-cards
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:
        archived_state
         per-page
         page
        """
        url = self._base_url + f"/projects/columns/{column_id}/cards"
        response = self._execute("get", url, payload)
        return response

    def create_a_project_card(self, column_id, payload=None):
        """
        Create a project card
        https://docs.github.com/rest/reference/projects#create-a-project-card
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/{column_id}/cards"
        response = self._execute("post", url, payload)
        return response

    def move_a_project_column(self, column_id, payload=None):
        """
        Move a project column
        https://docs.github.com/rest/reference/projects#move-a-project-column
        Attributes:
        Path Parameters:
        column_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/columns/{column_id}/moves"
        response = self._execute("post", url, payload)
        return response

    def get_a_project(self, project_id, payload=None):
        """
        Get a project
        https://docs.github.com/rest/reference/projects#get-a-project
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_project(self, project_id, payload=None):
        """
        Update a project
        https://docs.github.com/rest/reference/projects#update-a-project
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_project(self, project_id, payload=None):
        """
        Delete a project
        https://docs.github.com/rest/reference/projects#delete-a-project
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_project_collaborators(self, project_id, payload=None):
        """
        List project collaborators
        https://docs.github.com/rest/reference/projects#list-project-collaborators
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:
        affiliation
         per-page
         page
        """
        url = self._base_url + f"/projects/{project_id}/collaborators"
        response = self._execute("get", url, payload)
        return response

    def add_project_collaborator(self, project_id, username, payload=None):
        """
        Add project collaborator
        https://docs.github.com/rest/reference/projects#add-project-collaborator
        Attributes:
        Path Parameters:
        project_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}/collaborators/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_user_as_a_collaborator(self, project_id, username, payload=None):
        """
        Remove user as a collaborator
        https://docs.github.com/rest/reference/projects#remove-project-collaborator
        Attributes:
        Path Parameters:
        project_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}/collaborators/{username}"
        response = self._execute("delete", url, payload)
        return response

    def get_project_permission_for_a_user(self, project_id, username, payload=None):
        """
        Get project permission for a user
        https://docs.github.com/rest/reference/projects#get-project-permission-for-a-user
        Attributes:
        Path Parameters:
        project_id
        username
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}/collaborators/{username}/permission"
        response = self._execute("get", url, payload)
        return response

    def list_project_columns(self, project_id, payload=None):
        """
        List project columns
        https://docs.github.com/rest/reference/projects#list-project-columns
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/projects/{project_id}/columns"
        response = self._execute("get", url, payload)
        return response

    def create_a_project_column(self, project_id, payload=None):
        """
        Create a project column
        https://docs.github.com/rest/reference/projects#create-a-project-column
        Attributes:
        Path Parameters:
        project_id
        Payload Parameters:

        """
        url = self._base_url + f"/projects/{project_id}/columns"
        response = self._execute("post", url, payload)
        return response

    def list_repository_projects(self, owner, repo, payload=None):
        """
        List repository projects
        https://docs.github.com/rest/reference/projects#list-repository-projects
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        state
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/projects"
        response = self._execute("get", url, payload)
        return response

    def create_a_repository_project(self, owner, repo, payload=None):
        """
        Create a repository project
        https://docs.github.com/rest/reference/projects#create-a-repository-project
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/projects"
        response = self._execute("post", url, payload)
        return response

    def create_a_user_project(self, payload=None):
        """
        Create a user project
        https://docs.github.com/rest/reference/projects#create-a-user-project
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/projects"
        response = self._execute("post", url, payload)
        return response

    def list_user_projects(self, username, payload=None):
        """
        List user projects
        https://docs.github.com/rest/reference/projects#list-user-projects
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        state
         per-page
         page
        """
        url = self._base_url + f"/users/{username}/projects"
        response = self._execute("get", url, payload)
        return response



"""
Manage access of OAuth applications
"""


class OauthAuthorizations:
    """
    Manage access of OAuth applications
    """

    def __init__(self, client):
        """
        Initialize the OauthAuthorizations class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_your_grants(self, payload=None):
        """
        List your grants
        https://docs.github.com/rest/reference/oauth-authorizations#list-your-grants
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
         client_id
        """
        url = self._base_url + "/applications/grants"
        response = self._execute("get", url, payload)
        return response

    def get_a_single_grant(self, grant_id, payload=None):
        """
        Get a single grant
        https://docs.github.com/rest/reference/oauth-authorizations#get-a-single-grant
        Attributes:
        Path Parameters:
        grant_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/grants/{grant_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_grant(self, grant_id, payload=None):
        """
        Delete a grant
        https://docs.github.com/rest/reference/oauth-authorizations#delete-a-grant
        Attributes:
        Path Parameters:
        grant_id
        Payload Parameters:

        """
        url = self._base_url + f"/applications/grants/{grant_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_your_authorizations(self, payload=None):
        """
        List your authorizations
        https://docs.github.com/rest/reference/oauth-authorizations#list-your-authorizations
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
         client_id
        """
        url = self._base_url + "/authorizations"
        response = self._execute("get", url, payload)
        return response

    def create_a_new_authorization(self, payload=None):
        """
        Create a new authorization
        https://docs.github.com/rest/reference/oauth-authorizations#create-a-new-authorization
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/authorizations"
        response = self._execute("post", url, payload)
        return response

    def get_or_create_an_authorization_for_a_specific_app(self, client_id, payload=None):
        """
        Get-or-create an authorization for a specific app
        https://docs.github.com/rest/reference/oauth-authorizations#get-or-create-an-authorization-for-a-specific-app
        Attributes:
        Path Parameters:

        Payload Parameters:
        client_secret
        """
        url = self._base_url + f"/authorizations/clients/{client_id}"
        response = self._execute("put", url, payload)
        return response

    def get_or_create_an_authorization_for_a_specific_app_and_fingerprint(
        self, fingerprint, client_id, payload=None
    ):
        """
        Get-or-create an authorization for a specific app and fingerprint
        https://docs.github.com/rest/reference/oauth-authorizations#get-or-create-an-authorization-for-a-specific-app-and-fingerprint
        Attributes:
        Path Parameters:
        fingerprint
        client_id
        Payload Parameters:
        client_secret
        """
        url = self._base_url + f"/authorizations/clients/{client_id}/{fingerprint}"
        response = self._execute("put", url, payload)
        return response

    def get_a_single_authorization(self, authorization_id, payload=None):
        """
        Get a single authorization
        https://docs.github.com/rest/reference/oauth-authorizations#get-a-single-authorization
        Attributes:
        Path Parameters:
        authorization_id
        Payload Parameters:

        """
        url = self._base_url + f"/authorizations/{authorization_id}"
        response = self._execute("get", url, payload)
        return response

    def update_an_existing_authorization(self, authorization_id, payload=None):
        """
        Update an existing authorization
        https://docs.github.com/rest/reference/oauth-authorizations#update-an-existing-authorization
        Attributes:
        Path Parameters:
        authorization_id
        Payload Parameters:

        """
        url = self._base_url + f"/authorizations/{authorization_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_an_authorization(self, authorization_id, payload=None):
        """
        Delete an authorization
        https://docs.github.com/rest/reference/oauth-authorizations#delete-an-authorization
        Attributes:
        Path Parameters:
        authorization_id
        Payload Parameters:

        """
        url = self._base_url + f"/authorizations/{authorization_id}"
        response = self._execute("delete", url, payload)
        return response



"""
Init file for apis package.
"""
# flake8: noqa
from .actions import actions
from .activity import activity
from .apps import apps
from .billing import billing
from .checks import checks
from .code_scanning import code_scanning
from .codes_of_conduct import codes_of_conduct
from .codespaces import codespaces
from .dependabot import dependabot
from .dependency_graph import dependency_graph
from .emojis import emojis
from .enterprise_admin import enterprise_admin
from .gists import gists
from .git import git
from .gitignore import gitignore
from .interactions import interactions
from .issues import issues
from .licenses import licenses
from .markdown import markdown
from .meta import meta
from .migrations import migrations
from .oauth_authorizations import oauth_authorizations
from .oidc import oidc
from .orgs import orgs
from .packages import packages
from .projects import projects
from .pulls import pulls
from .rate_limit import rate_limit
from .reactions import reactions
from .repos import repos
from .scim import scim
from .search import search
from .secret_scanning import secret_scanning
from .server_statistics import server_statistics
from .teams import teams
from .users import users



"""
Endpoints to manage Dependabot.
"""


class Dependabot:
    """
    Endpoints to manage Dependabot.
    """

    def __init__(self, client):
        """
        Initialize the Dependabot class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organization_secrets(self, org, payload=None):
        """
        List organization secrets
        https://docs.github.com/rest/reference/dependabot#list-organization-secrets
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_public_key(self, org, payload=None):
        """
        Get an organization public key
        https://docs.github.com/rest/reference/dependabot#get-an-organization-public-key
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_secret(self, org, secret_name, payload=None):
        """
        Get an organization secret
        https://docs.github.com/rest/reference/dependabot#get-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_an_organization_secret(self, org, secret_name, payload=None):
        """
        Create or update an organization secret
        https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_an_organization_secret(self, org, secret_name, payload=None):
        """
        Delete an organization secret
        https://docs.github.com/rest/reference/dependabot#delete-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response

    def list_selected_repositories_for_an_organization_secret(self, org, secret_name, payload=None):
        """
        List selected repositories for an organization secret
        https://docs.github.com/rest/reference/dependabot#list-selected-repositories-for-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories"
        response = self._execute("get", url, payload)
        return response

    def set_selected_repositories_for_an_organization_secret(self, org, secret_name, payload=None):
        """
        Set selected repositories for an organization secret
        https://docs.github.com/rest/reference/dependabot#set-selected-repositories-for-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories"
        response = self._execute("put", url, payload)
        return response

    def add_selected_repository_to_an_organization_secret(
        self, org, secret_name, repository_id, payload=None
    ):
        """
        Add selected repository to an organization secret
        https://docs.github.com/rest/reference/dependabot#add-selected-repository-to-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_selected_repository_from_an_organization_secret(
        self, org, secret_name, repository_id, payload=None
    ):
        """
        Remove selected repository from an organization secret
        https://docs.github.com/rest/reference/dependabot#remove-selected-repository-from-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/dependabot/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_repository_secrets(self, owner, repo, payload=None):
        """
        List repository secrets
        https://docs.github.com/rest/reference/dependabot#list-repository-secrets
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_public_key(self, owner, repo, payload=None):
        """
        Get a repository public key
        https://docs.github.com/rest/reference/dependabot#get-a-repository-public-key
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Get a repository secret
        https://docs.github.com/rest/reference/dependabot#get-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Create or update a repository secret
        https://docs.github.com/rest/reference/dependabot#create-or-update-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Delete a repository secret
        https://docs.github.com/rest/reference/dependabot#delete-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/dependabot/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response



"""
Rich interactions with checks run by your integrations.
"""


class Checks:
    """
    Rich interactions with checks run by your integrations.
    """

    def __init__(self, client):
        """
        Initialize the Checks class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def create_a_check_run(self, owner, repo, payload=None):
        """
        Create a check run
        https://docs.github.com/rest/reference/checks#create-a-check-run
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-runs"
        response = self._execute("post", url, payload)
        return response

    def get_a_check_run(self, owner, repo, check_run_id, payload=None):
        """
        Get a check run
        https://docs.github.com/rest/reference/checks#get-a-check-run
        Attributes:
        Path Parameters:
        owner
        repo
        check_run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-runs/{check_run_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_check_run(self, owner, repo, check_run_id, payload=None):
        """
        Update a check run
        https://docs.github.com/rest/reference/checks#update-a-check-run
        Attributes:
        Path Parameters:
        owner
        repo
        check_run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-runs/{check_run_id}"
        response = self._execute("patch", url, payload)
        return response

    def list_check_run_annotations(self, owner, repo, check_run_id, payload=None):
        """
        List check run annotations
        https://docs.github.com/rest/reference/checks#list-check-run-annotations
        Attributes:
        Path Parameters:
        owner
        repo
        check_run_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-runs/{check_run_id}/annotations"
        response = self._execute("get", url, payload)
        return response

    def rerequest_a_check_run(self, owner, repo, check_run_id, payload=None):
        """
        Rerequest a check run
        https://docs.github.com/rest/reference/checks#rerequest-a-check-run
        Attributes:
        Path Parameters:
        owner
        repo
        check_run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-runs/{check_run_id}/rerequest"
        response = self._execute("post", url, payload)
        return response

    def create_a_check_suite(self, owner, repo, payload=None):
        """
        Create a check suite
        https://docs.github.com/rest/reference/checks#create-a-check-suite
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-suites"
        response = self._execute("post", url, payload)
        return response

    def update_repository_preferences_for_check_suites(self, owner, repo, payload=None):
        """
        Update repository preferences for check suites
        https://docs.github.com/rest/reference/checks#update-repository-preferences-for-check-suites
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-suites/preferences"
        response = self._execute("patch", url, payload)
        return response

    def get_a_check_suite(self, owner, repo, check_suite_id, payload=None):
        """
        Get a check suite
        https://docs.github.com/rest/reference/checks#get-a-check-suite
        Attributes:
        Path Parameters:
        owner
        repo
        check_suite_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-suites/{check_suite_id}"
        response = self._execute("get", url, payload)
        return response

    def list_check_runs_in_a_check_suite(self, owner, repo, check_suite_id, payload=None):
        """
        List check runs in a check suite
        https://docs.github.com/rest/reference/checks#list-check-runs-in-a-check-suite
        Attributes:
        Path Parameters:
        owner
        repo
        check_suite_id
        Payload Parameters:
        check-name
         status
         filter
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-suites/{check_suite_id}/check-runs"
        response = self._execute("get", url, payload)
        return response

    def rerequest_a_check_suite(self, owner, repo, check_suite_id, payload=None):
        """
        Rerequest a check suite
        https://docs.github.com/rest/reference/checks#rerequest-a-check-suite
        Attributes:
        Path Parameters:
        owner
        repo
        check_suite_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/check-suites/{check_suite_id}/rerequest"
        response = self._execute("post", url, payload)
        return response

    def list_check_runs_for_a_git_reference(self, owner, repo, ref, payload=None):
        """
        List check runs for a Git reference
        https://docs.github.com/rest/reference/checks#list-check-runs-for-a-git-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        check-name
         status
         filter
         per-page
         page
         app_id
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{ref}/check-runs"
        response = self._execute("get", url, payload)
        return response

    def list_check_suites_for_a_git_reference(self, owner, repo, ref, payload=None):
        """
        List check suites for a Git reference
        https://docs.github.com/rest/reference/checks#list-check-suites-for-a-git-reference
        Attributes:
        Path Parameters:
        owner
        repo
        ref
        Payload Parameters:
        app_id
         check-name
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/commits/{ref}/check-suites"
        response = self._execute("get", url, payload)
        return response



"""
Endpoints to manage GitHub OIDC configuration using the REST API.
"""


class Oidc:
    """
    Endpoints to manage GitHub OIDC configuration using the REST API.
    """

    def __init__(self, client):
        """
        Initialize the Oidc class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_the_customization_template_for_an_oidc_subject_claim_for_an_organization(
        self, org, payload=None
    ):
        """
        Get the customization template for an OIDC subject claim for an organization
        https://docs.github.com/rest/actions/oidc#get-the-customization-template-for-an-oidc-subject-claim-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/oidc/customization/sub"
        response = self._execute("get", url, payload)
        return response

    def set_the_customization_template_for_an_oidc_subject_claim_for_an_organization(
        self, org, payload=None
    ):
        """
        Set the customization template for an OIDC subject claim for an organization
        https://docs.github.com/rest/actions/oidc#set-the-customization-template-for-an-oidc-subject-claim-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/oidc/customization/sub"
        response = self._execute("put", url, payload)
        return response



"""
This module containst the RestClient class.
"""

import os

import requests

from . import apis


class RestClientError(Exception):
    """
    Exception raised when a REST request fails.
    """


class RestClient:
    # pylint: disable=too-few-public-methods
    # pylint: disable=too-many-instance-attributes
    """
    The following methods are used to form requests to the GitHub REST API.
    """

    def __init__(self, rest_api_url=None, api_token=None):
        """
        Initialize the REST client to make requests to the GitHub API.

        Attributes:
            headers (dict): Headers to be used in the requests.
            base_url (str): Base URL of the GitHub API.
            API_TOKEN (str): GitHub API token.
            REST_API_URL (str): GitHub REST API URL.
        """
        if api_token is None:
            api_token = os.environ.get("API_TOKEN")
            if os.environ.get("API_TOKEN") is None:
                raise RestClientError("API_TOKEN environment variable is not set")
        self._headers = {"Authorization": f"Bearer {api_token}"}
        if rest_api_url is None:
            rest_api_url = os.environ.get("REST_API_URL", r"https://api.github.com")
        self._base_url = rest_api_url

        self.actions = apis.actions.Actions(self)
        self.activity = apis.activity.Activity(self)
        self.apps = apis.apps.Apps(self)
        self.billing = apis.billing.Billing(self)
        self.checks = apis.checks.Checks(self)
        self.code_scanning = apis.code_scanning.CodeScanning(self)
        self.codes_of_conduct = apis.codes_of_conduct.CodesOfConduct(self)
        self.codespaces = apis.codespaces.Codespaces(self)
        self.dependabot = apis.dependabot.Dependabot(self)
        self.dependency_graph = apis.dependency_graph.DependencyGraph(self)
        self.emojis = apis.emojis.Emojis(self)
        self.enterprise_admin = apis.enterprise_admin.EnterpriseAdmin(self)
        self.gists = apis.gists.Gists(self)
        self.git = apis.git.Git(self)
        self.gitignore = apis.gitignore.Gitignore(self)
        self.interactions = apis.interactions.Interactions(self)
        self.issues = apis.issues.Issues(self)
        self.licenses = apis.licenses.Licenses(self)
        self.markdown = apis.markdown.Markdown(self)
        self.meta = apis.meta.Meta(self)
        self.migrations = apis.migrations.Migrations(self)
        self.oauth_authorizations = apis.oauth_authorizations.OauthAuthorizations(self)
        self.oidc = apis.oidc.Oidc(self)
        self.orgs = apis.orgs.Orgs(self)
        self.packages = apis.packages.Packages(self)
        self.projects = apis.projects.Projects(self)
        self.pulls = apis.pulls.Pulls(self)
        self.rate_limit = apis.rate_limit.RateLimit(self)
        self.reactions = apis.reactions.Reactions(self)
        self.repos = apis.repos.Repos(self)
        self.scim = apis.scim.Scim(self)
        self.search = apis.search.Search(self)
        self.secret_scanning = apis.secret_scanning.SecretScanning(self)
        self.server_statistics = apis.server_statistics.ServerStatistics(self)
        self.teams = apis.teams.Teams(self)
        self.users = apis.users.Users(self)

    def _execute(self, method, url, payload):
        """
        Execute a request.

        Attributes:
            method (str): HTTP method.
            url (str): URL.
            payload (dict): Payload.
        """
        try:
            response = requests.request(method=method, url=url, json=payload, headers=self._headers)
            response.raise_for_status()
            return response
        except requests.exceptions.Timeout as errtimeout:
            raise RestClientError(f"Timeout error: {errtimeout}") from errtimeout
        except requests.exceptions.HTTPError as errhttp:
            raise RestClientError(f"HTTP error: {errhttp}") from errhttp
        except requests.exceptions.TooManyRedirects as errredirect:
            raise RestClientError(f"Too many redirects: {errredirect}") from errredirect
        except requests.exceptions.RequestException as errexcept:
            raise RestClientError(f"Unexpected error: {errexcept}") from errexcept



"""
Interact with GitHub Pull Requests.
"""


class Pulls:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Pull Requests.
    """

    def __init__(self, client):
        """
        Initialize the Pulls class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_pull_requests(self, owner, repo, payload=None):
        """
        List pull requests
        https://docs.github.com/rest/reference/pulls#list-pull-requests
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        state
         head
         base
         sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls"
        response = self._execute("get", url, payload)
        return response

    def create_a_pull_request(self, owner, repo, payload=None):
        """
        Create a pull request
        https://docs.github.com/rest/reference/pulls#create-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls"
        response = self._execute("post", url, payload)
        return response

    def list_review_comments_in_a_repository(self, owner, repo, payload=None):
        """
        List review comments in a repository
        https://docs.github.com/rest/reference/pulls#list-review-comments-in-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments"
        response = self._execute("get", url, payload)
        return response

    def get_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
        """
        Get a review comment for a pull request
        https://docs.github.com/rest/reference/pulls#get-a-review-comment-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
        """
        Update a review comment for a pull request
        https://docs.github.com/rest/reference/pulls#update-a-review-comment-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
        """
        Delete a review comment for a pull request
        https://docs.github.com/rest/reference/pulls#delete-a-review-comment-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Get a pull request
        https://docs.github.com/rest/reference/pulls#get-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Update a pull request
        https://docs.github.com/rest/reference/pulls/#update-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
        response = self._execute("patch", url, payload)
        return response

    def list_review_comments_on_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        List review comments on a pull request
        https://docs.github.com/rest/reference/pulls#list-review-comments-on-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:
        sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
        response = self._execute("get", url, payload)
        return response

    def create_a_review_comment_for_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Create a review comment for a pull request
        https://docs.github.com/rest/reference/pulls#create-a-review-comment-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
        response = self._execute("post", url, payload)
        return response

    def create_a_reply_for_a_review_comment(
        self, owner, repo, pull_number, comment_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Create a reply for a review comment
        https://docs.github.com/rest/reference/pulls#create-a-reply-for-a-review-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        comment_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments/{comment_id}/replies"
        )
        response = self._execute("post", url, payload)
        return response

    def list_commits_on_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        List commits on a pull request
        https://docs.github.com/rest/reference/pulls#list-commits-on-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/commits"
        response = self._execute("get", url, payload)
        return response

    def list_pull_requests_files(self, owner, repo, pull_number, payload=None):
        """
        List pull requests files
        https://docs.github.com/rest/reference/pulls#list-pull-requests-files
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/files"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_pull_request_has_been_merged(self, owner, repo, pull_number, payload=None):
        """
        Check if a pull request has been merged
        https://docs.github.com/rest/reference/pulls#check-if-a-pull-request-has-been-merged
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
        response = self._execute("get", url, payload)
        return response

    def merge_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Merge a pull request
        https://docs.github.com/rest/reference/pulls#merge-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
        response = self._execute("put", url, payload)
        return response

    def list_requested_reviewers_for_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        List requested reviewers for a pull request
        https://docs.github.com/rest/reference/pulls#list-requested-reviewers-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
        response = self._execute("get", url, payload)
        return response

    def request_reviewers_for_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Request reviewers for a pull request
        https://docs.github.com/rest/reference/pulls#request-reviewers-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
        response = self._execute("post", url, payload)
        return response

    def remove_requested_reviewers_from_a_pull_request(
        self, owner, repo, pull_number, payload=None
    ):
        """
        Remove requested reviewers from a pull request
        https://docs.github.com/rest/reference/pulls#remove-requested-reviewers-from-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
        response = self._execute("delete", url, payload)
        return response

    def list_reviews_for_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        List reviews for a pull request
        https://docs.github.com/rest/reference/pulls#list-reviews-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
        response = self._execute("get", url, payload)
        return response

    def create_a_review_for_a_pull_request(self, owner, repo, pull_number, payload=None):
        """
        Create a review for a pull request
        https://docs.github.com/rest/reference/pulls#create-a-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
        response = self._execute("post", url, payload)
        return response

    def get_a_review_for_a_pull_request(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Get a review for a pull request
        https://docs.github.com/rest/reference/pulls#get-a-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_review_for_a_pull_request(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Update a review for a pull request
        https://docs.github.com/rest/reference/pulls#update-a-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_pending_review_for_a_pull_request(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete a pending review for a pull request
        https://docs.github.com/rest/reference/pulls#delete-a-pending-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_comments_for_a_pull_request_review(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        List comments for a pull request review
        https://docs.github.com/rest/reference/pulls#list-comments-for-a-pull-request-review
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/comments"
        )
        response = self._execute("get", url, payload)
        return response

    def dismiss_a_review_for_a_pull_request(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Dismiss a review for a pull request
        https://docs.github.com/rest/reference/pulls#dismiss-a-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/dismissals"
        )
        response = self._execute("put", url, payload)
        return response

    def submit_a_review_for_a_pull_request(
        self, owner, repo, pull_number, review_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Submit a review for a pull request
        https://docs.github.com/rest/reference/pulls#submit-a-review-for-a-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        review_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/events"
        )
        response = self._execute("post", url, payload)
        return response

    def list_comments_in_a_pull_request_thread(
        self, owner, repo, pull_number, thread_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        List comments in a pull request thread
        https://docs.github.com/rest/reference/pulls#list-thread-comments-in-a-thread
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
        )
        response = self._execute("get", url, payload)
        return response

    def create_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Create a pull request thread comment
        https://docs.github.com/rest/reference/pulls#create-a-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
        )
        response = self._execute("post", url, payload)
        return response

    def get_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Get a pull request thread comment
        https://docs.github.com/rest/reference/pulls#get-a-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
        )
        response = self._execute("get", url, payload)
        return response

    def update_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Update a pull request thread comment
        https://docs.github.com/rest/reference/pulls#update-a-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
        )
        response = self._execute("patch", url, payload)
        return response

    def delete_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Delete a pull request thread comment
        https://docs.github.com/rest/reference/pulls#delete-a-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def update_a_pull_request_branch(self, owner, repo, pull_number, payload=None):
        """
        Update a pull request branch
        https://docs.github.com/rest/reference/pulls#update-a-pull-request-branch
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/update-branch"
        response = self._execute("put", url, payload)
        return response



"""
View gitignore templates
"""


class Gitignore:
    """
    View gitignore templates
    """

    def __init__(self, client):
        """
        Initialize the Gitignore class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_all_gitignore_templates(self, payload=None):
        """
        Get all gitignore templates
        https://docs.github.com/rest/reference/gitignore#get-all-gitignore-templates
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/gitignore/templates"
        response = self._execute("get", url, payload)
        return response

    def get_a_gitignore_template(self, name, payload=None):
        """
        Get a gitignore template
        https://docs.github.com/rest/reference/gitignore#get-a-gitignore-template
        Attributes:
        Path Parameters:
        name
        name
        Payload Parameters:

        """
        url = self._base_url + f"/gitignore/templates/{name}"
        response = self._execute("get", url, payload)
        return response



"""
This module is used to make requests through the GitHub GraphQL API.
"""
import os

from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport
from gql.transport.exceptions import TransportQueryError, TransportServerError

from . import graph_mutation, graph_query


class GraphClient:  # pylint: disable=too-few-public-methods
    """
    This following methods are used to form requests to the GitHub GraphQL API.
    """

    def __init__(self, graph_api_url=None, api_token=None):
        """
        Initialize the GraphQL client.
        """
        if api_token is None:
            api_token = os.environ.get("API_TOKEN")
            if os.environ.get("API_TOKEN") is None:
                raise GraphClientError("API_TOKEN environment variable is not set")
        self._headers = {"Authorization": f"Bearer {api_token}"}
        if graph_api_url is None:
            graph_api_url = os.environ.get("GRAPH_API_URL", r"https://api.github.com/graphql")
        headers = {"Authorization": f"Bearer {api_token}"}
        transport = AIOHTTPTransport(
            url=graph_api_url,
            headers=headers,
        )
        self._client = Client(transport=transport, fetch_schema_from_transport=True)

        self.query = graph_query.GraphQuery(self)
        self.mutation = graph_mutation.GraphMutation(self)

    def _load_query(self, path):
        """
        Load a query from a file.

        Attributes:
            path (str): Relative path to the query file.
        """
        absolute_path = os.path.dirname(__file__)
        relative_path = path
        full_path = os.path.join(absolute_path, relative_path)
        with open(full_path, encoding="utf8") as file:
            return gql(file.read())

    def _execute(self, query, params):
        """
        Execute a query.

        Attributes:
            query (str): GraphQL query.
            params (dict): Query parameters.
        """
        try:
            return self._client.execute(query, variable_values=params)
        except TransportQueryError as errquery:
            raise GraphClientError(errquery.errors[0].get("message")) from errquery
        except TransportServerError as errserver:
            raise GraphClientError(
                f"Server responded with a {str(errserver.code)} status code"
            ) from errserver


class GraphClientError(Exception):
    """
    Exception raised when an error occurs in the GraphClient.
    """



"""
Interact with GitHub Issues.
"""


class Issues:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Issues.
    """

    def __init__(self, client):
        """
        Initialize the Issues class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_issues_assigned_to_the_authenticated_user(self, payload=None):
        """
        List issues assigned to the authenticated user
        https://docs.github.com/rest/reference/issues#list-issues-assigned-to-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        filter
         state
         labels
         sort
         direction
         since
         collab
         orgs
         owned
         pulls
         per-page
         page
        """
        url = self._base_url + "/issues"
        response = self._execute("get", url, payload)
        return response

    def list_organization_issues_assigned_to_the_authenticated_user(self, org, payload=None):
        """
        List organization issues assigned to the authenticated user
        https://docs.github.com/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        filter
         state
         labels
         sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/issues"
        response = self._execute("get", url, payload)
        return response

    def list_assignees(self, owner, repo, payload=None):
        """
        List assignees
        https://docs.github.com/rest/reference/issues#list-assignees
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/assignees"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_user_can_be_assigned(self, owner, repo, assignee, payload=None):
        """
        Check if a user can be assigned
        https://docs.github.com/rest/reference/issues#check-if-a-user-can-be-assigned
        Attributes:
        Path Parameters:
        owner
        repo
        assignee
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/assignees/{assignee}"
        response = self._execute("get", url, payload)
        return response

    def list_repository_issues(self, owner, repo, payload=None):
        """
        List repository issues
        https://docs.github.com/rest/reference/issues#list-repository-issues
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        milestone
         state
         assignee
         creator
         mentioned
         labels
         sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues"
        response = self._execute("get", url, payload)
        return response

    def create_an_issue(self, owner, repo, payload=None):
        """
        Create an issue
        https://docs.github.com/rest/reference/issues#create-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues"
        response = self._execute("post", url, payload)
        return response

    def list_issue_comments_for_a_repository(self, owner, repo, payload=None):
        """
        List issue comments for a repository
        https://docs.github.com/rest/reference/issues#list-issue-comments-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments"
        response = self._execute("get", url, payload)
        return response

    def get_an_issue_comment(self, owner, repo, comment_id, payload=None):
        """
        Get an issue comment
        https://docs.github.com/rest/reference/issues#get-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
        response = self._execute("get", url, payload)
        return response

    def update_an_issue_comment(self, owner, repo, comment_id, payload=None):
        """
        Update an issue comment
        https://docs.github.com/rest/reference/issues#update-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_an_issue_comment(self, owner, repo, comment_id, payload=None):
        """
        Delete an issue comment
        https://docs.github.com/rest/reference/issues#delete-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_issue_events_for_a_repository(self, owner, repo, payload=None):
        """
        List issue events for a repository
        https://docs.github.com/rest/reference/issues#list-issue-events-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/events"
        response = self._execute("get", url, payload)
        return response

    def get_an_issue_event(self, owner, repo, event_id, payload=None):
        """
        Get an issue event
        https://docs.github.com/rest/reference/issues#get-an-issue-event
        Attributes:
        Path Parameters:
        owner
        repo
        event_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/events/{event_id}"
        response = self._execute("get", url, payload)
        return response

    def get_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Get an issue
        https://docs.github.com/rest/reference/issues#get-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
        response = self._execute("get", url, payload)
        return response

    def update_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Update an issue
        https://docs.github.com/rest/reference/issues/#update-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}"
        response = self._execute("patch", url, payload)
        return response

    def add_assignees_to_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Add assignees to an issue
        https://docs.github.com/rest/reference/issues#add-assignees-to-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
        response = self._execute("post", url, payload)
        return response

    def remove_assignees_from_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Remove assignees from an issue
        https://docs.github.com/rest/reference/issues#remove-assignees-from-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/assignees"
        response = self._execute("delete", url, payload)
        return response

    def list_issue_comments(self, owner, repo, issue_number, payload=None):
        """
        List issue comments
        https://docs.github.com/rest/reference/issues#list-issue-comments
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:
        since
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
        response = self._execute("get", url, payload)
        return response

    def create_an_issue_comment(self, owner, repo, issue_number, payload=None):
        """
        Create an issue comment
        https://docs.github.com/rest/reference/issues#create-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/comments"
        response = self._execute("post", url, payload)
        return response

    def list_issue_events(self, owner, repo, issue_number, payload=None):
        """
        List issue events
        https://docs.github.com/rest/reference/issues#list-issue-events
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/events"
        response = self._execute("get", url, payload)
        return response

    def list_labels_for_an_issue(self, owner, repo, issue_number, payload=None):
        """
        List labels for an issue
        https://docs.github.com/rest/reference/issues#list-labels-for-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
        response = self._execute("get", url, payload)
        return response

    def add_labels_to_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Add labels to an issue
        https://docs.github.com/rest/reference/issues#add-labels-to-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
        response = self._execute("post", url, payload)
        return response

    def set_labels_for_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Set labels for an issue
        https://docs.github.com/rest/reference/issues#set-labels-for-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
        response = self._execute("put", url, payload)
        return response

    def remove_all_labels_from_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Remove all labels from an issue
        https://docs.github.com/rest/reference/issues#remove-all-labels-from-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels"
        response = self._execute("delete", url, payload)
        return response

    def remove_a_label_from_an_issue(self, owner, repo, issue_number, name, payload=None):
        # pylint: disable=too-many-arguments
        """
        Remove a label from an issue
        https://docs.github.com/rest/reference/issues#remove-a-label-from-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/labels/{name}"
        response = self._execute("delete", url, payload)
        return response

    def lock_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Lock an issue
        https://docs.github.com/rest/reference/issues#lock-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
        response = self._execute("put", url, payload)
        return response

    def unlock_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Unlock an issue
        https://docs.github.com/rest/reference/issues#unlock-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/lock"
        response = self._execute("delete", url, payload)
        return response

    def list_timeline_events_for_an_issue(self, owner, repo, issue_number, payload=None):
        """
        List timeline events for an issue
        https://docs.github.com/rest/reference/issues#list-timeline-events-for-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/timeline"
        response = self._execute("get", url, payload)
        return response

    def list_labels_for_a_repository(self, owner, repo, payload=None):
        """
        List labels for a repository
        https://docs.github.com/rest/reference/issues#list-labels-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/labels"
        response = self._execute("get", url, payload)
        return response

    def create_a_label(self, owner, repo, payload=None):
        """
        Create a label
        https://docs.github.com/rest/reference/issues#create-a-label
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/labels"
        response = self._execute("post", url, payload)
        return response

    def get_a_label(self, owner, repo, name, payload=None):
        """
        Get a label
        https://docs.github.com/rest/reference/issues#get-a-label
        Attributes:
        Path Parameters:
        owner
        repo
        name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
        response = self._execute("get", url, payload)
        return response

    def update_a_label(self, owner, repo, name, payload=None):
        """
        Update a label
        https://docs.github.com/rest/reference/issues#update-a-label
        Attributes:
        Path Parameters:
        owner
        repo
        name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_label(self, owner, repo, name, payload=None):
        """
        Delete a label
        https://docs.github.com/rest/reference/issues#delete-a-label
        Attributes:
        Path Parameters:
        owner
        repo
        name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/labels/{name}"
        response = self._execute("delete", url, payload)
        return response

    def list_milestones(self, owner, repo, payload=None):
        """
        List milestones
        https://docs.github.com/rest/reference/issues#list-milestones
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        state
         sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones"
        response = self._execute("get", url, payload)
        return response

    def create_a_milestone(self, owner, repo, payload=None):
        """
        Create a milestone
        https://docs.github.com/rest/reference/issues#create-a-milestone
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones"
        response = self._execute("post", url, payload)
        return response

    def get_a_milestone(self, owner, repo, milestone_number, payload=None):
        """
        Get a milestone
        https://docs.github.com/rest/reference/issues#get-a-milestone
        Attributes:
        Path Parameters:
        owner
        repo
        milestone_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_milestone(self, owner, repo, milestone_number, payload=None):
        """
        Update a milestone
        https://docs.github.com/rest/reference/issues#update-a-milestone
        Attributes:
        Path Parameters:
        owner
        repo
        milestone_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_milestone(self, owner, repo, milestone_number, payload=None):
        """
        Delete a milestone
        https://docs.github.com/rest/reference/issues#delete-a-milestone
        Attributes:
        Path Parameters:
        owner
        repo
        milestone_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}"
        response = self._execute("delete", url, payload)
        return response

    def list_labels_for_issues_in_a_milestone(self, owner, repo, milestone_number, payload=None):
        """
        List labels for issues in a milestone
        https://docs.github.com/rest/reference/issues#list-labels-for-issues-in-a-milestone
        Attributes:
        Path Parameters:
        owner
        repo
        milestone_number
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/milestones/{milestone_number}/labels"
        response = self._execute("get", url, payload)
        return response

    def list_user_account_issues_assigned_to_the_authenticated_user(self, payload=None):
        """
        List user account issues assigned to the authenticated user
        https://docs.github.com/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        filter
         state
         labels
         sort
         direction
         since
         per-page
         page
        """
        url = self._base_url + "/user/issues"
        response = self._execute("get", url, payload)
        return response



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['octopy_admin',
 'octopy_admin.graph',
 'octopy_admin.rest',
 'octopy_admin.rest.apis',
 'octopy_admin.rest.apis.actions',
 'octopy_admin.rest.apis.activity',
 'octopy_admin.rest.apis.apps',
 'octopy_admin.rest.apis.billing',
 'octopy_admin.rest.apis.checks',
 'octopy_admin.rest.apis.code_scanning',
 'octopy_admin.rest.apis.codes_of_conduct',
 'octopy_admin.rest.apis.codespaces',
 'octopy_admin.rest.apis.dependabot',
 'octopy_admin.rest.apis.dependency_graph',
 'octopy_admin.rest.apis.emojis',
 'octopy_admin.rest.apis.enterprise_admin',
 'octopy_admin.rest.apis.gists',
 'octopy_admin.rest.apis.git',
 'octopy_admin.rest.apis.gitignore',
 'octopy_admin.rest.apis.interactions',
 'octopy_admin.rest.apis.issues',
 'octopy_admin.rest.apis.licenses',
 'octopy_admin.rest.apis.markdown',
 'octopy_admin.rest.apis.meta',
 'octopy_admin.rest.apis.migrations',
 'octopy_admin.rest.apis.oauth_authorizations',
 'octopy_admin.rest.apis.oidc',
 'octopy_admin.rest.apis.orgs',
 'octopy_admin.rest.apis.packages',
 'octopy_admin.rest.apis.projects',
 'octopy_admin.rest.apis.pulls',
 'octopy_admin.rest.apis.rate_limit',
 'octopy_admin.rest.apis.reactions',
 'octopy_admin.rest.apis.repos',
 'octopy_admin.rest.apis.scim',
 'octopy_admin.rest.apis.search',
 'octopy_admin.rest.apis.secret_scanning',
 'octopy_admin.rest.apis.server_statistics',
 'octopy_admin.rest.apis.teams',
 'octopy_admin.rest.apis.users']

package_data = \
{'': ['*'], 'octopy_admin.graph': ['gql_files/*']}

install_requires = \
['aiohttp>=3.8.1,<4.0.0',
 'gql>=3.4.0,<4.0.0',
 'pandas>=1.4.3,<2.0.0',
 'python-dotenv>=0.20.0,<0.21.0',
 'requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'octopy-admin',
    'version': '0.2.0',
    'description': 'octopy_admin is a python library for interacting with the GitHub GraphQL and REST APIs.',
    'long_description': None,
    'author': 'Brett Kuhlman',
    'author_email': 'kuhlman-labs@github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



"""
Interact with reactions to various GitHub entities.
"""


class Reactions:
    # pylint: disable=too-many-public-methods
    """
    Interact with reactions to various GitHub entities.
    """

    def __init__(self, client):
        """
        Initialize the Reactions class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_reactions_for_a_team_discussion_comment(
        self, org, team_slug, discussion_number, comment_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        List reactions for a team discussion comment
        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        Payload Parameters:
        content
         per-page
         page
        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_team_discussion_comment(
        self, org, team_slug, discussion_number, comment_number, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Create reaction for a team discussion comment
        https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion-comment
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("post", url, payload)
        return response

    def delete_team_discussion_comment_reaction(
        self, org, team_slug, discussion_number, comment_number, reaction_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Delete team discussion comment reaction
        https://docs.github.com/rest/reference/reactions#delete-team-discussion-comment-reaction
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        comment_number
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_team_discussion(self, org, team_slug, discussion_number, payload=None):
        """
        List reactions for a team discussion
        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:
        content
         per-page
         page
        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions"
        )
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_team_discussion(
        self, org, team_slug, discussion_number, payload=None
    ):
        """
        Create reaction for a team discussion
        https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions"
        )
        response = self._execute("post", url, payload)
        return response

    def delete_team_discussion_reaction(
        self, org, team_slug, discussion_number, reaction_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete team discussion reaction
        https://docs.github.com/rest/reference/reactions#delete-team-discussion-reaction
        Attributes:
        Path Parameters:
        org
        team_slug
        discussion_number
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_commit_comment(self, owner, repo, comment_id, payload=None):
        """
        List reactions for a commit comment
        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_commit_comment(self, owner, repo, comment_id, payload=None):
        """
        Create reaction for a commit comment
        https://docs.github.com/rest/reference/reactions#create-reaction-for-a-commit-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
        response = self._execute("post", url, payload)
        return response

    def delete_a_commit_comment_reaction(
        self, owner, repo, comment_id, reaction_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete a commit comment reaction
        https://docs.github.com/rest/reference/reactions#delete-a-commit-comment-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions/{reaction_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_an_issue_comment(self, owner, repo, comment_id, payload=None):
        """
        List reactions for an issue comment
        https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_an_issue_comment(self, owner, repo, comment_id, payload=None):
        """
        Create reaction for an issue comment
        https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
        response = self._execute("post", url, payload)
        return response

    def delete_an_issue_comment_reaction(
        self, owner, repo, comment_id, reaction_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete an issue comment reaction
        https://docs.github.com/rest/reference/reactions#delete-an-issue-comment-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions/{reaction_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_an_issue(self, owner, repo, issue_number, payload=None):
        """
        List reactions for an issue
        https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_an_issue(self, owner, repo, issue_number, payload=None):
        """
        Create reaction for an issue
        https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
        response = self._execute("post", url, payload)
        return response

    def delete_an_issue_reaction(
        self, owner, repo, issue_number, reaction_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete an issue reaction
        https://docs.github.com/rest/reference/reactions#delete-an-issue-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        issue_number
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions/{reaction_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_pull_request_review_comment(
        self, owner, repo, comment_id, payload=None
    ):
        """
        List reactions for a pull request review comment
        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-review-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_pull_request_review_comment(
        self, owner, repo, comment_id, payload=None
    ):
        """
        Create reaction for a pull request review comment
        https://docs.github.com/rest/reference/reactions#create-reaction-for-a-pull-request-review-comment
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
        response = self._execute("post", url, payload)
        return response

    def delete_a_pull_request_comment_reaction(
        self, owner, repo, comment_id, reaction_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Delete a pull request comment reaction
        https://docs.github.com/rest/reference/reactions#delete-a-pull-request-comment-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        comment_id
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions/{reaction_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        List reactions for a pull request thread comment
        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        Payload Parameters:
        content
         per-page
         page
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("get", url, payload)
        return response

    def create_a_reaction_to_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Create a reaction to a pull request thread comment
        https://docs.github.com/rest/reference/reactions#create-a-reaction-to-a-pull-request-thread-comment
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("post", url, payload)
        return response

    def delete_a_reaction_to_a_pull_request_thread_comment(
        self, owner, repo, pull_number, thread_id, comment_id, reaction_id, payload=None
    ):
        # pylint: disable=too-many-arguments
        """
        Delete a reaction to a pull request thread comment
        https://docs.github.com/rest/reference/reactions#delete-a-thread-comment-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        pull_number
        thread_id
        comment_id
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_release(self, owner, repo, release_id, payload=None):
        """
        List reactions for a release
        https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_release(self, owner, repo, release_id, payload=None):
        """
        Create reaction for a release
        https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-release
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
        response = self._execute("post", url, payload)
        return response

    def delete_a_release_reaction(
        self, owner, repo, release_id, reaction_id, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Delete a release reaction
        https://docs.github.com/rest/reference/reactions/#delete-a-release-reaction
        Attributes:
        Path Parameters:
        owner
        repo
        release_id
        reaction_id
        Payload Parameters:

        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions/{reaction_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_reactions_for_a_team_discussion_comment__legacy(
        self, team_id, discussion_number, comment_number, payload=None
    ):
        """
        List reactions for a team discussion comment (Legacy)
        https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        comment_number
        Payload Parameters:
        content
         per-page
         page
        """
        url = (
            self._base_url
            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_team_discussion_comment__legacy(
        self, team_id, discussion_number, comment_number, payload=None
    ):
        """
        Create reaction for a team discussion comment (Legacy)
        https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-comment-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        comment_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
        )
        response = self._execute("post", url, payload)
        return response

    def list_reactions_for_a_team_discussion__legacy(
        self, team_id, discussion_number, payload=None
    ):
        """
        List reactions for a team discussion (Legacy)
        https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:
        content
         per-page
         page
        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
        response = self._execute("get", url, payload)
        return response

    def create_reaction_for_a_team_discussion__legacy(
        self, team_id, discussion_number, payload=None
    ):
        """
        Create reaction for a team discussion (Legacy)
        https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-legacy
        Attributes:
        Path Parameters:
        team_id
        discussion_number
        Payload Parameters:

        """
        url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
        response = self._execute("post", url, payload)
        return response



"""
This module is used to make queries through the GitHub GraphQL API.
"""


class GraphQuery:
    """
    This class is used to get the data from the GraphQL API.
    """

    def __init__(self, client):
        """
        Initialize the GraphQuery class.
        """
        self._execute = client._execute
        self._load_query = client._load_query

    def _get_page_info(self, results):
        """
        This module returns a dictionary of the page info from a GraphQL query.

        Attributes:
            results (dict): The results of a GraphQL query.
        """
        while results.get("pageInfo") is None:
            for _, item in results.items():
                if isinstance(item, dict):
                    if item.get("pageInfo") is None:
                        results = item
                        return self._get_page_info(results)
                    return item.get("pageInfo")

    def _get_nodes(self, results):
        """
        This module returns a list of nodes from a GraphQL query.

        Attributes:
            results (dict): The results of a GraphQL query.
        """

        while results.get("nodes") or results.get("edges") is None:
            for _, item in results.items():
                if isinstance(item, dict):
                    if item.get("nodes"):
                        return item.get("nodes")
                    if item.get("nodes") == []:
                        return []
                    if item.get("edges"):
                        return item.get("edges")
                    if item.get("edges") == []:
                        return []
                    return self._get_nodes(item)

    def _paginate_results(self, query, params):
        """
        This method returns a generator that will yield a dictionary
         of all results from a GraphQL query.

        Attributes:
            query (str): The GraphQL query.
            params (dict): The parameters to pass to the query.
        """
        cursor = None
        while True:
            params["cursor"] = cursor
            results = self._execute(query, params)
            page_info = self._get_page_info(results)
            next_page = page_info.get("hasNextPage")
            cursor = page_info.get("endCursor")
            yield results
            if not next_page:
                return

    def results_to_list(self, results):
        """
        This method returns a list of all results from the nodes or
        edges field in a GraphQL query.

        Attributes:
            results (dict): The results of a GraphQL query.
        """
        result_list = []
        for result in results:
            if self._get_nodes(result):
                result_list.extend(self._get_nodes(result))
        return result_list

    def get_enterprise_orgs(self, enterprise):
        """
        This module returns a generator that will yield a dictionary
         of all organizations in an Enterprise.

        Attributes:
            enterprise (str): The name of the Enterprise.

        """
        query = self._load_query("gql_files/get-enterprise-orgs.gql")
        params = {"slug": enterprise, "cursor": None}
        return self._paginate_results(query, params)

    def get_org_repos(self, org):
        """
        This module returns a generator that will yield a dictionary
        of all repositories in an organization.

        Attributes:
            org (str): The name of the Organization.
        """
        query = self._load_query("gql_files/get-org-repos.gql")
        params = {"organization": org, "cursor": None}
        return self._paginate_results(query, params)

    def get_repo_collaborators(self, org, repo):
        """
        This module returns a generator that will yield a dictionary
         of all collaborators in a repository.

        Attributes:
            org (str): The name of the Organization.
            repo (str): The name of the Repository.
        """
        query = self._load_query("gql_files/get-repo-collaborators.gql")
        params = {"owner": org, "name": repo, "cursor": None}
        return self._paginate_results(query, params)

    def get_repo_branch_protection_rules(self, org, repo):
        """
        This module returns a generator that will yield a dictionary
         of all branch protection rules in a repository.

        Attributes:
            org (str): The name of the Organization.
            repo (str): The name of the Repository.
        """
        query = self._load_query("gql_files/get-repo-branch-protection-rules.gql")
        params = {"owner": org, "name": repo, "cursor": None}
        return self._paginate_results(query, params)



"""
Endpoints that give information about the API.
"""


class Meta:
    """
    Endpoints that give information about the API.
    """

    def __init__(self, client):
        """
        Initialize the Meta class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def github_api_root(self, payload=None):
        """
        GitHub API Root
        https://docs.github.com/rest/overview/resources-in-the-rest-api#root-endpoint
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/"
        response = self._execute("get", url, payload)
        return response

    def get_github_meta_information(self, payload=None):
        """
        Get GitHub meta information
        https://docs.github.com/rest/reference/meta#get-github-meta-information
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/meta"
        response = self._execute("get", url, payload)
        return response

    def get_octocat(self, payload=None):
        """
        Get Octocat
        https://docs.github.com/rest/reference/meta#get-octocat
        Attributes:
        Path Parameters:

        Payload Parameters:
        s
        """
        url = self._base_url + "/octocat"
        response = self._execute("get", url, payload)
        return response

    def get_all_api_versions(self, payload=None):
        """
        Get all API versions
        https://docs.github.com/rest/reference/meta#get-all-api-versions
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/versions"
        response = self._execute("get", url, payload)
        return response

    def get_the_zen_of_github(self, payload=None):
        """
        Get the Zen of GitHub
        N/A
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/zen"
        response = self._execute("get", url, payload)
        return response



"""
Retrieve code scanning alerts from a repository.
"""


class CodeScanning:
    """
    Retrieve code scanning alerts from a repository.
    """

    def __init__(self, client):
        """
        Initialize the CodeScanning class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_code_scanning_alerts_for_an_enterprise(self, enterprise, payload=None):
        """
        List code scanning alerts for an enterprise
        https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        tool-name
         tool-guid
         pagination-before
         pagination-after
         page
         per-page
         direction
         state
         sort
        """
        url = self._base_url + f"/enterprises/{enterprise}/code-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def list_code_scanning_alerts_for_an_organization(self, org, payload=None):
        """
        List code scanning alerts for an organization
        https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-by-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        tool-name
         tool-guid
         pagination-before
         pagination-after
         page
         per-page
         direction
         state
         sort
        """
        url = self._base_url + f"/orgs/{org}/code-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def list_code_scanning_alerts_for_a_repository(self, owner, repo, payload=None):
        """
        List code scanning alerts for a repository
        https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        tool-name
         tool-guid
         page
         per-page
         git-ref
         direction
         sort
         state
        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts"
        response = self._execute("get", url, payload)
        return response

    def get_a_code_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        Get a code scanning alert
        https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}"
        response = self._execute("get", url, payload)
        return response

    def update_a_code_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        Update a code scanning alert
        https://docs.github.com/rest/reference/code-scanning#update-a-code-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}"
        response = self._execute("patch", url, payload)
        return response

    def list_instances_of_a_code_scanning_alert(self, owner, repo, alert_number, payload=None):
        """
        List instances of a code scanning alert
        https://docs.github.com/rest/reference/code-scanning#list-instances-of-a-code-scanning-alert
        Attributes:
        Path Parameters:
        owner
        repo
        alert_number
        Payload Parameters:
        page
         per-page
         git-ref
        """
        url = (
            self._base_url + f"/repos/{owner}/{repo}/code-scanning/alerts/{alert_number}/instances"
        )
        response = self._execute("get", url, payload)
        return response

    def list_code_scanning_analyses_for_a_repository(self, owner, repo, payload=None):
        """
        List code scanning analyses for a repository
        https://docs.github.com/rest/reference/code-scanning#list-code-scanning-analyses-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        tool-name
         tool-guid
         page
         per-page
         ref
         sarif_id
        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses"
        response = self._execute("get", url, payload)
        return response

    def get_a_code_scanning_analysis_for_a_repository(self, owner, repo, analysis_id, payload=None):
        """
        Get a code scanning analysis for a repository
        https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-analysis-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        analysis_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses/{analysis_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_code_scanning_analysis_from_a_repository(
        self, owner, repo, analysis_id, payload=None
    ):
        """
        Delete a code scanning analysis from a repository
        https://docs.github.com/rest/reference/code-scanning#delete-a-code-scanning-analysis-from-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        analysis_id
        Payload Parameters:
        confirm_delete
        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/analyses/{analysis_id}"
        response = self._execute("delete", url, payload)
        return response

    def run_codeql_queries_against_one_or_more_repositories(self, owner, repo, payload=None):
        """
        Run CodeQL queries against one or more repositories
        https://docs.github.com/rest/reference/code-scanning#run-codeql-queries-against-one-or-more-repositories
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/queries"
        response = self._execute("post", url, payload)
        return response

    def put_a_summary_status_report_for_building_a_codeql_database(self, owner, repo, payload=None):
        """
        Put a summary status report for building a CodeQL database
        N/A
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/codeql/status"
        response = self._execute("put", url, payload)
        return response

    def upload_an_analysis_as_sarif_data(self, owner, repo, payload=None):
        """
        Upload an analysis as SARIF data
        https://docs.github.com/rest/reference/code-scanning#upload-a-sarif-file
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/sarifs"
        response = self._execute("post", url, payload)
        return response

    def get_information_about_a_sarif_upload(self, owner, repo, sarif_id, payload=None):
        """
        Get information about a SARIF upload
        https://docs.github.com/rest/reference/code-scanning#list-recent-code-scanning-analyses-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        sarif_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/code-scanning/sarifs/{sarif_id}"
        response = self._execute("get", url, payload)
        return response



"""
List emojis available to use on GitHub.
"""


class Emojis:
    # pylint: disable=too-few-public-methods
    """
    List emojis available to use on GitHub.
    """

    def __init__(self, client):
        """
        Initialize the Emojis class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_emojis(self, payload=None):
        """
        Get emojis
        https://docs.github.com/rest/reference/emojis#get-emojis
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/emojis"
        response = self._execute("get", url, payload)
        return response
